Player class

Constructors

Player(dynamic actor)

Properties

actor ↔ Object3D
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isWalking ↔ bool
getter/setter pair
name ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userid ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited