Session class

Constructors

Session(dynamic url)

Properties

hashCode → int
The hash code for this object.
no setterinherited
headers ↔ Map<String, String>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url ↔ String
getter/setter pair

Methods

get() → Future<Response>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
post(dynamic data) → Future<Response>
toString() → String
A string representation of this object.
inherited
updateCookie(Response response) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited