GLTFDracoMeshCompressionExtension class

Inheritance

Constructors

GLTFDracoMeshCompressionExtension(dynamic json, dynamic dracoLoader)

Properties

createNodeAttachment ↔ Function?
getter/setter pairinherited
createNodeMesh ↔ Function?
getter/setter pairinherited
dracoLoader ↔ dynamic
getter/setter pair
extendMaterialParams ↔ Function?
getter/setter pairinherited
getMaterialType ↔ Function?
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
json ↔ dynamic
getter/setter pair
loadBufferView ↔ Function?
getter/setter pairinherited
loadMaterial ↔ Function?
getter/setter pairinherited
loadMesh ↔ Function?
getter/setter pairinherited
loadTexture ↔ Function?
getter/setter pairinherited
name ↔ String
getter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decodePrimitive(dynamic primitive, dynamic parser) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited