GLTFRegistry class

Constructors

GLTFRegistry()

Properties

hashCode → int
The hash code for this object.
no setterinherited
objects ↔ Map
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(dynamic key, dynamic object) → dynamic
get(dynamic key) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(dynamic key) → dynamic
removeAll() → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited