GLTFTextureWebPExtension class

Inheritance

Constructors

GLTFTextureWebPExtension(dynamic parser)

Properties

createNodeAttachment ↔ Function?
getter/setter pairinherited
createNodeMesh ↔ Function?
getter/setter pairinherited
extendMaterialParams ↔ Function?
getter/setter pairinherited
getMaterialType ↔ Function?
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
isSupported ↔ bool?
getter/setter pair
loadBufferView ↔ Function?
getter/setter pairinherited
loadMaterial ↔ Function?
getter/setter pairinherited
loadMesh ↔ Function?
getter/setter pairinherited
loadTexture ↔ Function?
getter/setter pairinherited
name ↔ String
getter/setter pairoverride
parser ↔ dynamic
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

detectSupport() → dynamic
loadTexture2(dynamic textureIndex) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited