DragControls class

Mixed-in types

Constructors

DragControls(List<Object3D> objects, dynamic camera, dynamic listenableKey)

Properties

camera ↔ Camera
getter/setter pair
enabled ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
listenableKey ↔ GlobalKey<DomLikeListenableState>
getter/setter pair
objects ↔ List<Object3D>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope ↔ DragControls
getter/setter pair
transformGroup ↔ bool
getter/setter pair

Methods

activate() → dynamic
addEventListener(String type, Function listener) → void
inherited
clearListeners() → void
inherited
deactivate() → dynamic
dispatchEvent(Event event) → void
inherited
dispose() → dynamic
getObjects() → dynamic
getRaycaster() → dynamic
hasEventListener(String type, Function? listener) → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onPointerCancel() → dynamic
onPointerDown(dynamic event) → dynamic
onPointerMove(dynamic event) → dynamic
removeEventListener(String type, Function listener) → void
inherited
toString() → String
A string representation of this object.
inherited
updatePointer(dynamic event) → dynamic

Operators

operator ==(Object other) → bool
The equality operator.
inherited