DirectGeometry class

Constructors

DirectGeometry()

Properties

boundingBox ↔ Box3?
getter/setter pair
boundingSphere ↔ Sphere?
getter/setter pair
colors ↔ List<Color>
getter/setter pair
colorsNeedUpdate ↔ bool
getter/setter pair
groups ↔ List<Map<String, int>>
getter/setter pair
groupsNeedUpdate ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int
getter/setter pair
lineDistancesNeedUpdate ↔ bool
getter/setter pair
morphTargets ↔ Map<String, dynamic>
getter/setter pair
name ↔ String
getter/setter pair
normals ↔ List<Vector3>
getter/setter pair
normalsNeedUpdate ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skinIndices ↔ List<Vector4>
getter/setter pair
skinWeights ↔ List<Vector4>
getter/setter pair
type ↔ String
getter/setter pair
uuid ↔ String
getter/setter pair
uvs ↔ List<Vector2>
getter/setter pair
uvs2 ↔ List<Vector2>
getter/setter pair
uvsNeedUpdate ↔ bool
getter/setter pair
vertices ↔ List<Vector3>
getter/setter pair
verticesNeedUpdate ↔ bool
getter/setter pair

Methods

computeGroups(dynamic geometry) → dynamic
fromGeometry(Geometry geometry) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited