Face3 class

Constructors

Face3(dynamic a, dynamic b, dynamic c, dynamic normal, dynamic color, {int materialIndex = 0})

Properties

a ↔ int
getter/setter pair
b ↔ int
getter/setter pair
c ↔ int
getter/setter pair
color ↔ Color
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
materialIndex ↔ int
getter/setter pair
normal ↔ Vector3
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vertexColors ↔ List<Color>
getter/setter pair
vertexNormals ↔ List<Vector3>
getter/setter pair

Methods

clone() → dynamic
copy(Face3 source) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited