MorphTarget class

Constructors

MorphTarget(Map<String, dynamic>? json)

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String
getter/setter pair
normals ↔ List<Vector3>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vertices ↔ List<Vector3>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited