Tri class

Constructors

Tri(Vertex? v1, Vertex? v2, Vertex? v3, int a, int b, int c)

Properties

a ↔ int
getter/setter pair
b ↔ int
getter/setter pair
c ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
normal ↔ Vector3
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
v1 ↔ Vertex?
getter/setter pair
v2 ↔ Vertex?
getter/setter pair
v3 ↔ Vertex?
getter/setter pair

Methods

computeNormal() → void
hasVertex(Vertex v) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replaceVertex(Vertex oldv, Vertex newv) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited