Vertex class

Constructors

Vertex(Vector3 v)

Properties

collapseCost ↔ double
getter/setter pair
collapseNeighbor ↔ Vertex?
getter/setter pair
costCount ↔ int
getter/setter pair
faces ↔ List<Tri?>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int
getter/setter pair
minCost ↔ double
getter/setter pair
neighbors ↔ List<Vertex>
getter/setter pair
position ↔ Vector3
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalCost ↔ double
getter/setter pair
v ↔ Vector3
getter/setter pair

Methods

addUniqueNeighbor(Vertex? vertex) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeIfNonNeighbor(Vertex? n) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited