BufferGeometryUtils class

Constructors

BufferGeometryUtils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

computeTangents(dynamic geometry, [bool negateSign = true]) → dynamic
mergeVertices(BufferGeometry geometry, [double tolerance = 1e-4]) → BufferGeometry
@param {BufferGeometry} geometry @param {number} tolerance @return {BufferGeometry>}