VolumetricFire class

Inheritance

Constructors

VolumetricFire(dynamic width, dynamic height, dynamic depth, dynamic sliceSpacing, dynamic camera, {dynamic color})

Properties

camera ↔ Camera
getter/setter pair
cornerNeighbors ↔ List<List<int>>
getter/setter pair
fs ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
incomingEdges ↔ List<List<int>>
getter/setter pair
mesh ↔ Mesh
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vs ↔ String
getter/setter pair

Methods

init() → dynamic
initMaterial() → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
slice() → dynamic
toString() → String
A string representation of this object.
inherited
update(dynamic frameTime, dynamic elapsed) → dynamic
override
updateGeometry() → dynamic
updateViewVector() → dynamic

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

fireProfile ↔ Texture?
getter/setter pair
nzw ↔ Texture?
getter/setter pair
texturePath ↔ String
getter/setter pair