Node class

Implementers

Constructors

Node([dynamic nodeType = null])

Properties

constant ↔ bool
getter/setter pair
generateLength ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inputType ↔ dynamic
getter/setter pair
nodeType ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → dynamic
no setter
updateType ↔ NodeUpdateType
getter/setter pair
uuid ↔ String
getter/setter pair
value ↔ dynamic
getter/setter pair
w ↔ dynamic
getter/setter pair
xyz ↔ dynamic
getter/setter pair

Methods

build(NodeBuilder builder, [dynamic output = null]) → dynamic
generate([dynamic builder, dynamic output]) → dynamic
getHash([dynamic builder]) → dynamic
getNodeType([dynamic builder, dynamic output]) → dynamic
getProperty(String name) → dynamic
getUpdateType([dynamic builder]) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
update([dynamic frame]) → dynamic

Operators

operator ==(Object other) → bool
The equality operator.
inherited