NodeFrame class

Constructors

NodeFrame()

Properties

camera ↔ dynamic
getter/setter pair
deltaTime ↔ num
getter/setter pair
frameId ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastTime ↔ dynamic
getter/setter pair
material ↔ dynamic
getter/setter pair
object ↔ dynamic
getter/setter pair
renderer ↔ dynamic
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ num?
getter/setter pair
time ↔ num
getter/setter pair
updateMap ↔ WeakMap
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
update() → dynamic
updateNode(dynamic node) → dynamic

Operators

operator ==(Object other) → bool
The equality operator.
inherited