NodeFunction class

Implementers

Constructors

NodeFunction(dynamic type, dynamic inputs, [dynamic name = '', dynamic presicion = ''])

Properties

hashCode → int
The hash code for this object.
no setterinherited
inputs ↔ dynamic
getter/setter pair
name ↔ String
getter/setter pair
presicion ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ dynamic
getter/setter pair

Methods

getCode() → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited