NodeFunctionInput class

Constructors

NodeFunctionInput(dynamic type, dynamic name, [dynamic count = null, dynamic qualifier = '', dynamic isConst = false])

Properties

count ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isConst ↔ bool
getter/setter pair
name ↔ String
getter/setter pair
qualifier ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited