NodeKeywords class

Constructors

NodeKeywords()

Properties

hashCode → int
The hash code for this object.
no setterinherited
keywords ↔ List
getter/setter pair
keywordsCallback ↔ Map
getter/setter pair
nodes ↔ List
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addKeyword(dynamic name, dynamic callback) → dynamic
getNode(dynamic name) → dynamic
include(dynamic builder, dynamic code) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(dynamic code) → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited