KeyframeTrack class

Implementers

Constructors

KeyframeTrack(dynamic name, dynamic times, dynamic values, [dynamic interpolation])

Properties

createInterpolant ↔ Function?
getter/setter pair
DefaultInterpolation ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
TimeBufferType ↔ String
getter/setter pair
times ↔ List<num>
getter/setter pair
ValueBufferType ↔ String
getter/setter pair
values ↔ List<num>
getter/setter pair
ValueTypeName ↔ String
getter/setter pair

Methods

clone() → dynamic
getInterpolation() → dynamic
getValueSize() → dynamic
InterpolantFactoryMethodDiscrete(dynamic result) → dynamic
InterpolantFactoryMethodLinear(dynamic result) → dynamic
InterpolantFactoryMethodSmooth(dynamic result) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
optimize() → dynamic
scale(dynamic timeScale) → dynamic
setInterpolation(dynamic interpolation) → dynamic
shift(dynamic timeOffset) → dynamic
toString() → String
A string representation of this object.
inherited
trim(dynamic startTime, dynamic endTime) → dynamic
validate() → dynamic

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

toJSON(dynamic track) → dynamic