PropertyMixer class

Constructors

PropertyMixer(PropertyBinding binding, String typeName, int valueSize)

Properties

binding ↔ PropertyBinding
getter/setter pair
buffer ↔ List
getter/setter pair
cumulativeWeight ↔ int
getter/setter pair
cumulativeWeightAdditive ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
referenceCount ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
useCount ↔ int
getter/setter pair
valueSize ↔ int
getter/setter pair

Methods

accumulate(int accuIndex, int weight) → dynamic
accumulateAdditive(int weight) → dynamic
apply(dynamic accuIndex) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
restoreOriginalState() → dynamic
saveOriginalState() → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited