SpriteAnimator class

Constructors

SpriteAnimator()

Properties

animations ↔ List
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(dynamic options) → dynamic
free(dynamic animation) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
update(dynamic delta) → dynamic

Operators

operator ==(Object other) → bool
The equality operator.
inherited