BufferGeometry class

Mixed-in types
Implementers

Constructors

BufferGeometry()
BufferGeometry.fromJSON(Map<String, dynamic> json, Map<String, dynamic> rootJSON)

Properties

attributes ↔ Map<String, dynamic>
getter/setter pair
boundingBox ↔ Box3?
getter/setter pair
boundingSphere ↔ Sphere?
getter/setter pair
colors ↔ List<Color>
getter/setter pair
colorsNeedUpdate ↔ bool
getter/setter pair
curveSegments ↔ num
getter/setter pair
directGeometry ↔ dynamic
getter/setter pair
drawRange ↔ Map<String, int>
getter/setter pair
elementsNeedUpdate ↔ bool
getter/setter pair
groups ↔ List<Map<String, dynamic>>
getter/setter pair
groupsNeedUpdate ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int
getter/setter pair
index ↔ BufferAttribute<NativeArray<num>>?
getter/setter pair
instanceCount ↔ int?
getter/setter pair
lineDistances ↔ List<num>
getter/setter pair
lineDistancesNeedUpdate ↔ bool
getter/setter pair
maxInstanceCount ↔ int?
getter/setter pair
morphAttributes ↔ Map<String, List<BufferAttribute<NativeArray<num>>>>
getter/setter pair
morphTargets ↔ dynamic
getter/setter pair
morphTargetsRelative ↔ bool
getter/setter pair
name ↔ String
getter/setter pair
normalsNeedUpdate ↔ bool
getter/setter pair
parameters ↔ Map<String, dynamic>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shapes ↔ List<Shape>
getter/setter pair
type ↔ String
getter/setter pair
userData ↔ Map<String, dynamic>
getter/setter pair
uuid ↔ String
getter/setter pair
uvsNeedUpdate ↔ bool
getter/setter pair
verticesNeedUpdate ↔ bool
getter/setter pair

Methods

addEventListener(String type, Function listener) → void
inherited
addGroup(int start, int count, [int materialIndex = 0]) → void
applyMatrix4(Matrix4 matrix) → void
applyQuaternion(Quaternion q) → BufferGeometry
center() → void
clearGroups() → void
clearListeners() → void
inherited
clone() → BufferGeometry
computeBoundingBox() → void
computeBoundingSphere() → void
computeFaceNormals() → void
computeTangents() → void
computeVertexNormals() → void
copy(BufferGeometry source) → BufferGeometry
deleteAttribute(String name) → BufferGeometry
dispatchEvent(Event event) → void
inherited
dispose() → void
getAttribute(String name) → dynamic
getIndex() → BufferAttribute<NativeArray<num>>?
hasAttribute(String name) → bool
hasEventListener(String type, Function? listener) → bool
inherited
lookAt(Vector3 vector) → BufferGeometry
merge(BufferGeometry geometry, [int? offset]) → BufferGeometry
normalizeNormals() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeEventListener(String type, Function listener) → void
inherited
rotateX(num angle) → BufferGeometry
rotateY(num angle) → BufferGeometry
rotateZ(num angle) → BufferGeometry
scale(num x, num y, num z) → BufferGeometry
setAttribute(String name, dynamic attribute) → BufferGeometry
setDrawRange(int start, int count) → void
setFromPoints(dynamic points) → BufferGeometry
setIndex(dynamic index) → void
toJSON({Object3dMeta? meta}) → Map<String, dynamic>
toNonIndexed() → BufferGeometry
toString() → String
A string representation of this object.
inherited
translate(num x, num y, num z) → BufferGeometry
translateWithVector3(Vector3 v3) → BufferGeometry

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

castJSON(Map<String, dynamic> json, Map<String, dynamic> rootJSON) → BufferGeometry