Clock class

Constructors

Clock([bool? autoStart])

Properties

autoStart ↔ bool
getter/setter pair
elapsedTime ↔ num
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
oldTime ↔ num
getter/setter pair
running ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ num
getter/setter pair

Methods

getDelta() → num
getElapsedTime() → num
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start() → void
stop() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited