InterleavedBuffer class

Implementers

Constructors

InterleavedBuffer(NativeArray<num> array, int stride)

Properties

array ↔ NativeArray<num>
getter/setter pair
count ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isInterleavedBuffer ↔ bool
getter/setter pair
needsUpdate ← bool
no getter
onUploadCallback ↔ Function?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stride ↔ int
getter/setter pair
type ↔ String
getter/setter pair
updateRange ↔ Map<String, dynamic>
getter/setter pair
usage ↔ int
getter/setter pair
uuid ↔ String
getter/setter pair
version ↔ int
getter/setter pair

Methods

clone(dynamic data) → dynamic
copy(InterleavedBuffer source) → InterleavedBuffer
copyAt(int index1, InterleavedBuffer attribute, int index2) → InterleavedBuffer
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onUpload(Function callback) → InterleavedBuffer
setUsage(int value) → InterleavedBuffer
toJSON(dynamic data) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited