InterleavedBufferAttribute class

Inheritance

Constructors

InterleavedBufferAttribute(InterleavedBuffer? data, int _itemSize, int offset, bool _normalized)

Properties

array ↔ NativeArray<num>
getter/setter pairinherited-setteroverride-getter
buffer ↔ int?
getter/setter pairinherited
count ↔ int
getter/setter pairinherited-setteroverride-getter
data ↔ InterleavedBuffer?
getter/setter pairoverride
elementSize ↔ int?
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
isBufferAttribute ↔ bool
getter/setter pairinherited
itemSize ↔ int
getter/setter pairinherited
length → int
no setterinherited
name ↔ String?
getter/setter pairinherited
needsUpdate ← bool
no getteroverride
normalized ↔ bool
getter/setter pairinherited
offset ↔ int
getter/setter pair
onUploadCallback ↔ void Function()?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String
getter/setter pairinherited
updateRange ↔ Map<String, int>?
getter/setter pairinherited
usage ↔ int
getter/setter pairinherited
version ↔ int
getter/setter pairinherited

Methods

applyMatrix3(Matrix3 m) → BufferAttribute<NativeArray<num>>
inherited
applyMatrix4(Matrix4 m) → InterleavedBufferAttribute
override
applyNormalMatrix(dynamic m) → InterleavedBufferAttribute
override
clone() → BufferAttribute<NativeArray<num>>
inherited
copy(BufferAttribute<NativeArray<num>> source) → BufferAttribute<NativeArray<num>>
inherited
copyArray(NativeArray<num> array) → BufferAttribute<NativeArray<num>>
inherited
copyAt(int index1, BufferAttribute<NativeArray<num>> attribute, int index2) → BufferAttribute<NativeArray<num>>
inherited
copyColorsArray(List<Color> colors) → BufferAttribute<NativeArray<num>>
inherited
copyVector2sArray(List<Vector2> vectors) → BufferAttribute<NativeArray<num>>
inherited
copyVector3sArray(List<Vector3> vectors) → BufferAttribute<NativeArray<num>>
inherited
copyVector4sArray(List<Vector4> vectors) → BufferAttribute<NativeArray<num>>
inherited
getAt(int index) → num?
inherited
getW(int index) → num?
override
getX(int index) → num?
override
getY(int index) → num?
override
getZ(int index) → num?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onUpload(void callback()?) → BufferAttribute<NativeArray<num>>
inherited
set(dynamic value, {int offset = 0}) → BufferAttribute<NativeArray<num>>
inherited
setUsage(int value) → BufferAttribute<NativeArray<num>>
inherited
setW(int index, dynamic w) → InterleavedBufferAttribute
override
setX(int index, dynamic x) → InterleavedBufferAttribute
override
setXY(int index, dynamic x, dynamic y) → InterleavedBufferAttribute
override
setXYZ(int index, num x, num y, num z) → InterleavedBufferAttribute
override
setXYZW(int index, dynamic x, dynamic y, dynamic z, dynamic w) → InterleavedBufferAttribute
override
setY(int index, dynamic y) → InterleavedBufferAttribute
override
setZ(int index, dynamic z) → InterleavedBufferAttribute
override
toJSON([dynamic data]) → Map<String, Object>
override
toString() → String
A string representation of this object.
inherited
transformDirection(Matrix4 m) → InterleavedBufferAttribute
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited