Intersection class

Constructors

Intersection(Map<String, dynamic> json)

Properties

distance ↔ num
getter/setter pair
distanceToRay ↔ num
getter/setter pair
face ↔ Face?
getter/setter pair
faceIndex ↔ num
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
index ↔ num
getter/setter pair
instanceId ↔ num
getter/setter pair
object ↔ Object3D
getter/setter pair
point ↔ Vector3
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uv ↔ Vector2
getter/setter pair
uv2 ↔ Vector2?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited