Font class

Implementers

Constructors

Font()

Properties

data ↔ Map<String, dynamic>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isFont ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String
getter/setter pair

Methods

generateShapes(dynamic text, {double size = 100}) → List<Shape>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited