Node class

Constructors

Node(dynamic i, dynamic x, dynamic y)

Properties

hashCode → int
The hash code for this object.
no setterinherited
i ↔ num
getter/setter pair
next ↔ Node?
getter/setter pair
nextZ ↔ Node?
getter/setter pair
prev ↔ Node?
getter/setter pair
prevZ ↔ Node?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
steiner ↔ bool
getter/setter pair
x ↔ num
getter/setter pair
y ↔ num
getter/setter pair
z ↔ num?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited