ShapePath class

Constructors

ShapePath()

Properties

color ↔ Color
getter/setter pair
currentPath ↔ Path
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subPaths ↔ List<Path>
getter/setter pair
type ↔ String
getter/setter pair
userData ↔ Map<String, dynamic>?
getter/setter pair

Methods

bezierCurveTo(num aCP1x, num aCP1y, num aCP2x, num aCP2y, num aX, num aY) → dynamic
lineTo(num x, num y) → dynamic
moveTo(num x, num y) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
quadraticCurveTo(num aCPx, num aCPy, num aX, num aY) → dynamic
splineThru(dynamic pts) → dynamic
toShapes(bool isCCW, bool noHoles) → List<Shape>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited