SpotLightShadow class

Inheritance

Constructors

SpotLightShadow()

Properties

autoUpdate ↔ bool
getter/setter pairinherited
bias ↔ num
getter/setter pairinherited
blurSamples ↔ num
getter/setter pairinherited
camera ↔ Camera?
getter/setter pairinherited
focus ↔ num
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
map ↔ RenderTarget?
getter/setter pairinherited
mapPass ↔ RenderTarget?
getter/setter pairinherited
mapSize ↔ Vector2
getter/setter pairinherited
matrix ↔ Matrix4
getter/setter pairinherited
needsUpdate ↔ bool
getter/setter pairinherited
normalBias ↔ num
getter/setter pairinherited
radius ↔ num
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clone() → LightShadow
inherited
copy(LightShadow source) → SpotLightShadow
override
dispose() → void
inherited
getFrameExtents() → Vector2
inherited
getFrustum() → Frustum
inherited
getViewport(int viewportIndex) → Vector4
inherited
getViewportCount() → num
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited
updateMatrices(Light light, {int viewportIndex = 0}) → void
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited