FileLoader class

Inheritance

Constructors

FileLoader(dynamic manager)

Properties

crossOrigin ↔ String
getter/setter pairinherited
flipY ↔ bool
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
manager ↔ LoadingManager
getter/setter pairinherited
mimeType ↔ String
getter/setter pairinherited
path ↔ String
getter/setter pairinherited
requestHeader ↔ Map<String, dynamic>
getter/setter pairinherited
resourcePath ↔ String?
getter/setter pairinherited
responseType ↔ String
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
withCredentials ↔ bool
getter/setter pairinherited

Methods

load(dynamic url, Function onLoad, [Function? onProgress, Function? onError]) → dynamic
override
loadAsync(dynamic url) → Future
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(dynamic json, [String path = '', Function? onLoad, Function? onError]) → dynamic
inherited
setCrossOrigin(String crossOrigin) → Loader
inherited
setMimeType(dynamic value) → dynamic
setPath(String path) → Loader
inherited
setRequestHeader(Map<String, dynamic> requestHeader) → Loader
inherited
setResourcePath(String? resourcePath) → Loader
inherited
setResponseType(dynamic value) → dynamic
setWithCredentials(bool value) → Loader
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited