Loader class abstract

Implementers

Constructors

Loader([dynamic manager])

Properties

crossOrigin ↔ String
getter/setter pair
flipY ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
manager ↔ LoadingManager
getter/setter pair
mimeType ↔ String
getter/setter pair
path ↔ String
getter/setter pair
requestHeader ↔ Map<String, dynamic>
getter/setter pair
resourcePath ↔ String?
getter/setter pair
responseType ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
withCredentials ↔ bool
getter/setter pair

Methods

load(dynamic url, Function onLoad, [Function? onProgress, Function? onError]) → dynamic
loadAsync(dynamic url) → Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(dynamic json, [String path = '', Function? onLoad, Function? onError]) → dynamic
setCrossOrigin(String crossOrigin) → Loader
setPath(String path) → Loader
setRequestHeader(Map<String, dynamic> requestHeader) → Loader
setResourcePath(String? resourcePath) → Loader
setWithCredentials(bool value) → Loader
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited