ConvexHull class

Constructors

ConvexHull()

Properties

assigned ↔ VertexList
getter/setter pair
faces ↔ List<Face2>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
newFace2s ↔ List<Face2>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tolerance ↔ num
getter/setter pair
unassigned ↔ VertexList
getter/setter pair
v1 ↔ Vector3
getter/setter pair
vertices ↔ List<VertexNode>
getter/setter pair

Methods

addAdjoiningFace2(dynamic eyeVertex, dynamic horizonEdge) → dynamic
addNewFace2s(dynamic eyeVertex, dynamic horizon) → ConvexHull
addVertexToFace2(VertexNode vertex, Face2 face) → ConvexHull
addVertexToHull(VertexNode eyeVertex) → ConvexHull
cleanup() → ConvexHull
compute() → ConvexHull
computeExtremes() → Map<String, List<VertexNode>>
computeHorizon(dynamic eyePoint, dynamic crossEdge, Face2 face, dynamic horizon) → ConvexHull
computeInitialHull() → ConvexHull
containsPoint(Vector3 point) → bool
deleteFace2Vertices(Face2 face, [Face2? absorbingFace2]) → ConvexHull
intersectRay(Ray ray, Vector3 target) → Vector3?
intersectsRay(Ray ray) → bool
makeEmpty() → ConvexHull
nextVertexToAdd() → VertexNode?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reindexFace2s() → ConvexHull
removeAllVerticesFromFace2(Face2 face) → VertexNode?
removeVertexFromFace2(VertexNode vertex, Face2 face) → ConvexHull
resolveUnassignedPoints(List<Face2> newFace2s) → ConvexHull
setFromObject(Object3D object) → ConvexHull
setFromPoints(List<Vector3> points) → ConvexHull
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited