Cylindrical class

Constructors

Cylindrical([num? radius, num? theta, num? y])

Properties

hashCode → int
The hash code for this object.
no setterinherited
radius ↔ num
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
theta ↔ num
getter/setter pair
y ↔ num
getter/setter pair

Methods

clone() → Cylindrical
copy(Cylindrical other) → Cylindrical
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(num radius, num theta, num y) → Cylindrical
setFromCartesianCoords(num x, num y, num z) → Cylindrical
setFromVector3(Vector3 v) → Cylindrical
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited