Euler class

Constructors

Euler([double? x, double? y, double? z, String? order])

Properties

hashCode → int
The hash code for this object.
no setterinherited
onChangeCallback ↔ Function
getter/setter pair
order ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String
getter/setter pair
x ↔ double
getter/setter pair
y ↔ double
getter/setter pair
z ↔ double
getter/setter pair

Methods

clone() → Euler
copy(Euler euler) → Euler
equals(Euler euler) → bool
fromArray(List<double> array) → Euler
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChange(Function callback) → void
reorder(String newOrder) → Euler
set(double x, double y, double z, [String? order]) → Euler
setFromQuaternion(Quaternion q, [String? order, bool update = false]) → Euler
setFromRotationMatrix(dynamic m, [String? order, bool? update]) → Euler
setFromVector3(Vector3 v, [String? order]) → Euler
toArray([List<num>? array, int offset = 0]) → List<num>
toJSON() → List<num>
toString() → String
A string representation of this object.
inherited
toVector3([Vector3? optionalResult]) → Vector3

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

DefaultOrder → const String
RotationOrders → const List<String>