Face2 class

Constructors

Face2()

Properties

area ↔ num
getter/setter pair
constant ↔ num
getter/setter pair
edge ↔ HalfEdge?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mark ↔ num
getter/setter pair
midpoint ↔ Vector3
getter/setter pair
normal ↔ Vector3
getter/setter pair
outside ↔ VertexNode?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

compute() → Face2
distanceToPoint(Vector3 point) → num
getEdge(num i) → HalfEdge?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create(VertexNode a, VertexNode b, VertexNode c) → Face2