HalfEdge class

Constructors

HalfEdge(VertexNode vertex, Face2 face)

Properties

face ↔ Face2
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
next ↔ HalfEdge?
getter/setter pair
prev ↔ HalfEdge?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
twin ↔ HalfEdge?
getter/setter pair
vertex ↔ VertexNode
getter/setter pair

Methods

length() → num
lengthSquared() → num
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setTwin(HalfEdge? edge) → HalfEdge
tail() → VertexNode?
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited