Line3 class

Constructors

Line3([Vector3? start, Vector3? end])

Properties

end ↔ Vector3
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start ↔ Vector3
getter/setter pair

Methods

applyMatrix4(Matrix4 matrix) → Line3
at(num t, Vector3 target) → Vector3
clone() → Line3
closestPointToPoint(Vector3 point, bool clampToLine, Vector3 target) → Vector3
closestPointToPointParameter(Vector3 point, bool clampToLine) → double
copy(Line3 line) → Line3
delta(Vector3 target) → Vector3
distance() → double
distanceSq() → num
equals(Line3 line) → bool
getCenter(Vector3 target) → Vector3
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(Vector3 start, Vector3 end) → Line3
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited