Math class

Constructors

Math()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

Infinity ↔ double
getter/setter pair
LN10 ↔ double
getter/setter pair
LN2 ↔ double
getter/setter pair
LOG2E ↔ double
getter/setter pair
MAX_SAFE_INTEGER ↔ int
getter/setter pair
MAX_VALUE ↔ double
getter/setter pair
SQRT1_2 ↔ double
getter/setter pair

Static Methods

abs(num x) → num
acos(num x) → double
asin(num x) → double
atan(double x) → double
atan2(num x, num y) → double
ceil(num x) → int
cos(num x) → double
exp(num x) → double
floor(num x) → int
log(num x) → num
log10(num x) → num
log2(num x) → double
max<T extends num>(T x, T y) → T
max3(num x, num y, num z) → num
min<T extends num>(T x, T y) → T
min3(num x, num y, num z) → num
pow(num x, num y) → num
randFloat(num low, num high) → double
randFloatSpread(num range) → double
random() → double
randomFromA2B(num a, num b) → double
round(num x) → int
sign(double x) → double
sin(num x) → double
sqrt(num x) → double
tan(num x) → double

Constants

EPSILON → const double
PI → const double