SphericalHarmonics3 class

Constructors

SphericalHarmonics3()

Properties

coefficients ↔ List<Vector3>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String
getter/setter pair

Methods

add(SphericalHarmonics3 sh) → SphericalHarmonics3
addScaledSH(SphericalHarmonics3 sh, num s) → SphericalHarmonics3
clone() → SphericalHarmonics3
copy(SphericalHarmonics3 sh) → SphericalHarmonics3
equals(SphericalHarmonics3 sh) → bool
fromArray(List<double> array, [int offset = 0]) → SphericalHarmonics3
getAt(Vector3 normal, Vector3 target) → Vector3
getIrradianceAt(Vector3 normal, Vector3 target) → Vector3
lerp(SphericalHarmonics3 sh, double alpha) → SphericalHarmonics3
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scale(num s) → SphericalHarmonics3
set(List<Vector3> coefficients) → SphericalHarmonics3
toArray(List<double> array, [int offset = 0]) → List<double>
toString() → String
A string representation of this object.
inherited
zero() → SphericalHarmonics3

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getBasisAt(Vector3 normal, List<double> shBasis) → dynamic