VertexList class

Constructors

VertexList()

Properties

hashCode → int
The hash code for this object.
no setterinherited
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tail ↔ VertexNode?
getter/setter pair

Methods

append(VertexNode vertex) → VertexList
appendChain(VertexNode vertex) → VertexList
clear() → VertexList
first() → VertexNode?
insertAfter(VertexNode target, VertexNode vertex) → VertexList
insertBefore(VertexNode target, VertexNode vertex) → VertexList
isEmpty() → bool
last() → VertexNode?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(VertexNode vertex) → VertexList
removeSubList(VertexNode a, VertexNode b) → VertexList
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited