VertexNode class

Constructors

VertexNode(Vector3 point)

Properties

face ↔ Face2?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
next ↔ VertexNode?
getter/setter pair
point ↔ Vector3
getter/setter pair
prev ↔ VertexNode?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited