RenderTarget class abstract

Mixed-in types
Implementers

Constructors

RenderTarget()

Properties

depth ↔ int
getter/setter pair
depthBuffer ↔ bool
getter/setter pair
depthTexture ↔ DepthTexture?
getter/setter pair
hasExternalTextures ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int
getter/setter pair
ignoreDepthForMultisampleCopy ↔ bool
getter/setter pair
isWebGLCubeRenderTarget ↔ bool
getter/setter pair
isWebGLMultipleRenderTargets ↔ bool
getter/setter pair
isWebGLMultisampleRenderTarget ↔ bool
getter/setter pair
isXRRenderTarget ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
samples ↔ int
getter/setter pair
scissor ↔ Vector4
getter/setter pair
scissorTest ↔ bool
getter/setter pair
stencilBuffer ↔ bool
getter/setter pair
texture ↔ dynamic
getter/setter pair
useMultisampleRenderbuffer ↔ bool
getter/setter pair
useMultisampleRenderToTexture ↔ bool
getter/setter pair
useRenderbuffer ↔ bool
getter/setter pair
useRenderToTexture ↔ bool
getter/setter pair
viewport ↔ Vector4
getter/setter pair
width ↔ int
getter/setter pair

Methods

addEventListener(String type, Function listener) → void
inherited
clearListeners() → void
inherited
clone() → WebGLRenderTarget
dispatchEvent(Event event) → void
inherited
dispose() → void
hasEventListener(String type, Function? listener) → bool
inherited
is3D() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeEventListener(String type, Function listener) → void
inherited
setSize(int width, int height, [int depth = 1]) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited