WebGLRenderer class

Constructors

WebGLRenderer(Map<String, dynamic>? parameters)

Properties

alpha ↔ bool
getter/setter pair
attributes ↔ WebGLAttributes
getter/setter pair
autoClear ↔ bool
getter/setter pair
autoClearColor ↔ bool
getter/setter pair
autoClearDepth ↔ bool
getter/setter pair
autoClearStencil ↔ bool
getter/setter pair
background ↔ WebGLBackground
getter/setter pair
bindingStates ↔ WebGLBindingStates
getter/setter pair
bufferRenderer ↔ BaseWebGLBufferRenderer
getter/setter pair
capabilities ↔ WebGLCapabilities
getter/setter pair
clipping ↔ WebGLClipping
getter/setter pair
clippingPlanes ↔ List<Plane>
getter/setter pair
cubemaps ↔ WebGLCubeMaps
getter/setter pair
cubeuvmaps ↔ WebGLCubeUVMaps
getter/setter pair
currentRenderList ↔ WebGLRenderList?
getter/setter pair
currentRenderState ↔ WebGLRenderState?
getter/setter pair
debug ↔ Map<String, dynamic>
getter/setter pair
depth ↔ bool
getter/setter pair
domElement ↔ dynamic
getter/setter pair
extensions ↔ WebGLExtensions
getter/setter pair
failIfMajorPerformanceCaveat ↔ bool
getter/setter pair
geometries ↔ WebGLGeometries
getter/setter pair
gl → dynamic
no setter
hashCode → int
The hash code for this object.
no setterinherited
height → double
no setter
indexedBufferRenderer ↔ WebGLIndexedBufferRenderer
getter/setter pair
info ↔ WebGLInfo
getter/setter pair
localClippingEnabled ↔ bool
getter/setter pair
materials ↔ WebGLMaterials
getter/setter pair
morphtargets ↔ WebGLMorphtargets
getter/setter pair
objects ↔ WebGLObjects
getter/setter pair
onAnimationFrameCallback ↔ void Function(double)?
getter/setter pair
outputEncoding ↔ int
getter/setter pair
parameters ↔ Map<String, dynamic>
getter/setter pair
physicallyCorrectLights ↔ bool
getter/setter pair
powerPreference ↔ String
getter/setter pair
premultipliedAlpha ↔ bool
getter/setter pair
preserveDrawingBuffer ↔ bool
getter/setter pair
programCache ↔ WebGLPrograms
getter/setter pair
projScreenMatrix ↔ Matrix4
getter/setter pair
properties ↔ WebGLProperties
getter/setter pair
renderLists ↔ WebGLRenderLists
getter/setter pair
renderListStack ↔ List<WebGLRenderList>
getter/setter pair
renderStates ↔ WebGLRenderStates
getter/setter pair
renderStateStack ↔ List<WebGLRenderState>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadowMap ↔ WebGLShadowMap
getter/setter pair
sortObjects ↔ bool
getter/setter pair
state ↔ WebGLState
getter/setter pair
stencil ↔ bool
getter/setter pair
textures ↔ WebGLTextures
getter/setter pair
toneMapping ↔ int
getter/setter pair
toneMappingExposure ↔ double
getter/setter pair
utils ↔ WebGLUtils
getter/setter pair
width → double
no setter
xr ↔ WebXRManager
getter/setter pair

Methods

clear([bool color = true, bool depth = true, bool stencil = true]) → void
clearColor() → void
clearDepth() → void
clearStencil() → void
compile(Object3D scene, Camera camera) → void
copyFramebufferToTexture(dynamic position, Texture texture, {int level = 0}) → void
copyTextureToTexture(dynamic position, Texture srcTexture, dynamic dstTexture, {int level = 0}) → void
copyTextureToTexture3D(Box3 sourceBox, Vector3 position, Texture srcTexture, Texture dstTexture, {int level = 0}) → void
deallocateMaterial(Material material) → void
dispose() → void
forceContextLoss() → void
forceContextRestore() → void
getActiveCubeFace() → int
getActiveMipmapLevel() → int
getClearAlpha() → double
getClearColor(Color target) → Color
getContext() → dynamic
getContextAttributes() → dynamic
getCurrentViewport(Vector4 target) → Vector4
getDrawingBufferSize(Vector2 target) → Vector2
getPixelRatio() → double
getProgram(Material material, Object3D? scene, Object3D object) → WebGLProgram
getRenderTarget() → RenderTarget?
getRenderTargetGLTexture(RenderTarget renderTarget) → int
getScissor(dynamic target) → dynamic
getScissorTest() → bool
getSize(Vector2 target) → Vector2
getTargetPixelRatio() → double
getViewport(Vector4 target) → Vector4
initGLContext() → void
initTexture(Texture texture) → void
markUniformsLightsNeedsUpdate(Map<String, dynamic> uniforms, dynamic value) → void
materialNeedsLights(Material material) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAnimationFrame(double time) → void
onContextRestore() → void
onMaterialDispose(Event event) → void
projectObject(Object3D object, Camera camera, int groupOrder, bool sortObjects) → void
readRenderTargetPixels(WebGLRenderTarget renderTarget, dynamic x, dynamic y, dynamic width, dynamic height, dynamic buffer, dynamic activeCubeFaceIndex) → void
releaseMaterialProgramReferences(Material material) → void
render(Object3D scene, Camera camera) → void
renderBufferDirect(Camera camera, Object3D? scene, BufferGeometry geometry, Material material, Object3D object, Map<String, dynamic>? group) → void
renderObject(Object3D object, dynamic scene, Camera camera, BufferGeometry geometry, Material material, Map<String, dynamic>? group) → void
renderObjects(List<RenderItem> renderList, Object3D scene, Camera camera) → void
renderScene(WebGLRenderList currentRenderList, Object3D scene, Camera camera, [Vector4? viewport]) → void
renderTransmissionPass(List<RenderItem> opaqueObjects, Object3D scene, Camera camera) → void
resetState() → void
setClearAlpha(double alpha) → void
setClearColor(Color color, [double alpha = 1.0]) → void
setDrawingBufferSize(double width, double height, double pixelRatio) → void
setOpaqueSort(Function? method) → void
setPixelRatio(double value) → void
setProgram(Camera camera, Object3D? scene, BufferGeometry? geometry, Material material, Object3D object) → WebGLProgram
setRenderTarget(RenderTarget? renderTarget, [int activeCubeFace = 0, int activeMipmapLevel = 0]) → void
setRenderTargetFramebuffer(RenderTarget renderTarget, dynamic defaultFramebuffer) → void
setRenderTargetTextures(RenderTarget renderTarget, dynamic colorTexture, dynamic depthTexture) → void
setScissor(num x, num y, num width, num height) → void
setScissorTest(bool boolean) → void
setSize(double width, double height, [bool updateStyle = false]) → void
setTransparentSort(Function? method) → void
setViewport(num x, num y, double width, double height) → void
toString() → String
A string representation of this object.
inherited
updateCommonMaterialProperties(Material material, dynamic parameters) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited