WebXRManager class

Mixed-in types

Constructors

WebXRManager(dynamic renderer, dynamic gl)

Properties

enabled ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addEventListener(String type, Function listener) → void
inherited
clearListeners() → void
inherited
dispatchEvent(Event event) → void
inherited
hasEventListener(String type, Function? listener) → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeEventListener(String type, Function listener) → void
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited