Fog class

Inheritance

Constructors

Fog(dynamic color, num? near, num? far)

Properties

color ↔ Color
getter/setter pairinherited
far ↔ num
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isFog ↔ bool
getter/setter pairoverride
isFogExp2 ↔ bool
getter/setter pairinherited
name ↔ String
getter/setter pairinherited
near ↔ num
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clone() → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() → dynamic
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited