FogExp2 class

Inheritance

Constructors

FogExp2(dynamic color, dynamic density)

Properties

color ↔ Color
getter/setter pairinherited
density ↔ num
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isFog ↔ bool
getter/setter pairinherited
isFogExp2 ↔ bool
getter/setter pairoverride
name ↔ String
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clone() → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() → dynamic
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited