RenderItem class

Constructors

RenderItem(Map<String, dynamic> json)

Properties

geometry ↔ BufferGeometry?
getter/setter pair
group ↔ Map<String, dynamic>?
getter/setter pair
groupOrder ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int
getter/setter pair
material ↔ Material?
getter/setter pair
object ↔ Object3D?
getter/setter pair
program ↔ dynamic
getter/setter pair
renderOrder ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
z ↔ double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited