WebGLClipping class

Constructors

WebGLClipping(WebGLProperties properties)

Properties

globalState ↔ dynamic
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
localClippingEnabled ↔ bool
getter/setter pair
numGlobalPlanes ↔ num
getter/setter pair
numIntersection ↔ num
getter/setter pair
numPlanes ↔ num
getter/setter pair
plane ↔ Plane
getter/setter pair
properties ↔ WebGLProperties
getter/setter pair
renderingShadows ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uniform ↔ Map<String, dynamic>
getter/setter pair
viewNormalMatrix ↔ Matrix3
getter/setter pair

Methods

beginShadows() → dynamic
endShadows() → dynamic
init(List<Plane> planes, bool enableLocalClipping, Camera camera) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
projectPlanes(dynamic planes, dynamic camera, dynamic dstOffset, dynamic skipTransform) → dynamic
resetGlobalState() → dynamic
setState(Material material, Camera camera, bool useCache) → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited