WebGLCubeUVMaps class

Constructors

WebGLCubeUVMaps(WebGLRenderer renderer)

Properties

cubeUVmaps ↔ WeakMap
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pmremGenerator ↔ dynamic
getter/setter pair
renderer ↔ WebGLRenderer
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → dynamic
get(Texture? texture) → Texture?
isCubeTextureComplete(dynamic image) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onTextureDispose(dynamic event) → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited