WebGLIndexedBufferRenderer class

Inheritance

Constructors

WebGLIndexedBufferRenderer(dynamic gl, WebGLExtensions extensions, WebGLInfo info, WebGLCapabilities capabilities)

Properties

bytesPerElement ↔ dynamic
getter/setter pair
capabilities ↔ WebGLCapabilities
getter/setter pair
extensions ↔ WebGLExtensions
getter/setter pair
gl ↔ dynamic
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
info ↔ WebGLInfo
getter/setter pair
isWebGL2 ↔ bool
getter/setter pair
mode ↔ dynamic
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ dynamic
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(dynamic start, dynamic count) → void
override
renderInstances(dynamic start, dynamic count, dynamic primcount) → dynamic
override
setIndex(dynamic value) → dynamic
override
setMode(dynamic value) → dynamic
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited