WebGLInfo class

Constructors

WebGLInfo(dynamic gl)

Properties

autoReset ↔ bool
getter/setter pair
gl ↔ dynamic
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
memory ↔ Map<String, int>
getter/setter pair
programs ↔ dynamic
getter/setter pair
render ↔ Map<String, num>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → dynamic
toString() → String
A string representation of this object.
inherited
update(dynamic count, dynamic mode, dynamic instanceCount) → dynamic

Operators

operator ==(Object other) → bool
The equality operator.
inherited