WebGLProperties class

Constructors

WebGLProperties()

Properties

hashCode → int
The hash code for this object.
no setterinherited
properties ↔ WeakMap<dynamic, Map<String, dynamic>?>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → dynamic
get(dynamic object) → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(dynamic object) → dynamic
toString() → String
A string representation of this object.
inherited
update(dynamic object, dynamic key, dynamic value) → dynamic

Operators

operator ==(Object other) → bool
The equality operator.
inherited