WebGLTextures class

Constructors

WebGLTextures(dynamic gl, WebGLExtensions extensions, WebGLState state, WebGLProperties properties, WebGLCapabilities capabilities, WebGLUtils utils, WebGLInfo info)

Properties

capabilities ↔ WebGLCapabilities
getter/setter pair
extensions ↔ WebGLExtensions
getter/setter pair
filterToGL ↔ Map<int, int>
getter/setter pair
gl ↔ dynamic
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
info ↔ WebGLInfo
getter/setter pair
isWebGL2 ↔ bool
getter/setter pair
maxCubemapSize ↔ int
getter/setter pair
maxSamples ↔ int
getter/setter pair
maxTextures ↔ int
getter/setter pair
maxTextureSize ↔ int
getter/setter pair
MultisampledRenderToTextureExtension ↔ dynamic
getter/setter pair
properties ↔ WebGLProperties
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ WebGLState
getter/setter pair
supportsInvalidateFramenbuffer ↔ bool
getter/setter pair
textureUnits ↔ int
getter/setter pair
utils ↔ WebGLUtils
getter/setter pair
wrappingToGL ↔ Map<int, int>
getter/setter pair

Methods

allocateTextureUnit() → int
deallocateRenderTarget(RenderTarget renderTarget) → void
deallocateTexture(Texture texture) → void
deleteTexture(Texture texture) → void
dispose() → void
filterFallback(int f) → dynamic
generateMipmap(dynamic target) → dynamic
getInternalFormat(dynamic internalFormatName, dynamic glFormat, dynamic glType, dynamic encoding, [bool isVideoTexture = false]) → dynamic
getMipLevels(Texture texture, dynamic image, dynamic supportsMips) → int
getRenderTargetSamples(RenderTarget renderTarget) → int
getTextureCacheKey(Texture texture) → String
initTexture(Map<String, dynamic> textureProperties, Texture texture) → bool
isPowerOfTwo(dynamic image) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onRenderTargetDispose(Event event) → void
onTextureDispose(Event event) → void
rebindTextures(RenderTarget renderTarget, dynamic colorTexture, dynamic depthTexture) → void
resetTextureUnits() → void
resizeImage(dynamic image, dynamic needsPowerOfTwo, dynamic needsNewCanvas, dynamic maxSize) → dynamic
setTexture2D(Texture texture, int slot) → void
setTexture2DArray(Texture texture, int slot) → void
setTexture3D(Texture texture, int slot) → void
setTextureCube(Texture texture, int slot) → void
setTextureParameters(dynamic textureType, Texture texture, dynamic supportsMips) → void
setupDepthRenderbuffer(RenderTarget renderTarget) → void
setupDepthTexture(dynamic framebuffer, RenderTarget renderTarget) → void
setupFrameBufferTexture(dynamic framebuffer, RenderTarget renderTarget, Texture texture, dynamic attachment, dynamic textureTarget) → void
setupRenderBufferStorage(dynamic renderbuffer, RenderTarget renderTarget, bool isMultisample) → void
setupRenderTarget(RenderTarget renderTarget) → void
textureNeedsGenerateMipmaps(Texture texture, dynamic supportsMips) → dynamic
textureNeedsPowerOfTwo(Texture texture) → dynamic
toString() → String
A string representation of this object.
inherited
updateMultisampleRenderTarget(RenderTarget renderTarget) → void
updateRenderTargetMipmap(RenderTarget renderTarget) → void
updateVideoTexture(VideoTexture texture) → void
uploadCubeTexture(Map<String, dynamic> textureProperties, Texture texture, dynamic slot) → void
uploadOpenGLTexture(Map<String, dynamic> textureProperties, OpenGLTexture texture, int slot) → void
uploadTexture(Map<String, dynamic> textureProperties, Texture texture, dynamic slot) → void
useMultisampledRenderToTexture(RenderTarget renderTarget) → bool
verifyColorSpace(Texture texture, dynamic image) → dynamic

Operators

operator ==(Object other) → bool
The equality operator.
inherited