WebGLUniforms class

Mixed-in types

Constructors

WebGLUniforms(dynamic gl, WebGLProgram program)

Properties

gl ↔ dynamic
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
map ↔ Map
getter/setter pairinherited
program ↔ WebGLProgram
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seq ↔ List
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setOptional(dynamic gl, dynamic object, dynamic name) → dynamic
setValue(dynamic gl, dynamic name, dynamic value, [WebGLTextures? textures]) → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

seqWithValue(List seq, Map<String, dynamic> values) → List
upload(dynamic gl, dynamic seq, dynamic values, dynamic textures) → dynamic