WebGLUtils class

Constructors

WebGLUtils(dynamic gl, WebGLExtensions extensions, WebGLCapabilities capabilities)

Properties

capabilities ↔ WebGLCapabilities
getter/setter pair
extensions ↔ WebGLExtensions
getter/setter pair
gl ↔ dynamic
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isWebGL2 ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

convert(dynamic p, [dynamic encoding]) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited