GPUBindingType class

Constructors

GPUBindingType()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

ComparisonSampler ↔ String
getter/setter pair
MultisampledTexture ↔ String
getter/setter pair
ReadonlyStorageBuffer ↔ String
getter/setter pair
ReadonlyStorageTexture ↔ String
getter/setter pair
SampledTexture ↔ String
getter/setter pair
Sampler ↔ String
getter/setter pair
StorageBuffer ↔ String
getter/setter pair
UniformBuffer ↔ String
getter/setter pair
WriteonlyStorageTexture ↔ String
getter/setter pair