WebGPUBindings class

Constructors

WebGPUBindings(dynamic device, dynamic info, dynamic properties, dynamic textures, dynamic renderPipelines, dynamic computePipelines, dynamic attributes, dynamic nodes)

Properties

attributes ↔ WebGPUAttributes
getter/setter pair
computePipelines ↔ WebGPUComputePipelines
getter/setter pair
device ↔ dynamic
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
info ↔ WebGPUInfo
getter/setter pair
nodes ↔ WebGPUNodes
getter/setter pair
properties ↔ WebGPUProperties
getter/setter pair
renderPipelines ↔ WebGPURenderPipelines
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textures ↔ WebGPUTextures
getter/setter pair
uniformsData ↔ WeakMap
getter/setter pair
updateMap ↔ WeakMap
getter/setter pair

Methods

dispose() → dynamic
get(dynamic object) → Map
getForCompute(dynamic param) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(dynamic object) → dynamic
toString() → String
A string representation of this object.
inherited
update(dynamic object) → dynamic

Operators

operator ==(Object other) → bool
The equality operator.
inherited