WebGPUInfo class

Constructors

WebGPUInfo()

Properties

autoReset ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
memory ↔ Map
getter/setter pair
render ↔ Map
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → dynamic
toString() → String
A string representation of this object.
inherited
update(dynamic object, dynamic count, dynamic instanceCount) → dynamic

Operators

operator ==(Object other) → bool
The equality operator.
inherited