WebGPUObjects class

Constructors

WebGPUObjects(dynamic geometries, dynamic info)

Properties

geometries ↔ WebGPUGeometries
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
info ↔ WebGPUInfo
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateMap ↔ WeakMap
getter/setter pair

Methods

dispose() → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
update(dynamic object) → dynamic

Operators

operator ==(Object other) → bool
The equality operator.
inherited