WebGPUProperties class

Constructors

WebGPUProperties()

Properties

hashCode → int
The hash code for this object.
no setterinherited
properties ↔ WeakMap
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → dynamic
get(dynamic object) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(dynamic object) → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited