WebGPURenderPipeline class

Constructors

WebGPURenderPipeline(dynamic device, dynamic renderer, dynamic sampleCount)

Properties

bindGroupLayout ↔ dynamic
getter/setter pair
cacheKey ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pipeline ↔ dynamic
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shaderAttributes ↔ dynamic
getter/setter pair
stageFragment ↔ WebGPUProgrammableStage
getter/setter pair
stageVertex ↔ WebGPUProgrammableStage
getter/setter pair
usedTimes ↔ int
getter/setter pair

Methods

init(dynamic cacheKey, WebGPUProgrammableStage stageVertex, WebGPUProgrammableStage stageFragment, dynamic object, dynamic nodeBuilder) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited