WebGPURenderPipelines class

Constructors

WebGPURenderPipelines(dynamic renderer, dynamic device, dynamic sampleCount, dynamic nodes, [dynamic bindings = null])

Properties

bindings ↔ dynamic
getter/setter pair
device ↔ dynamic
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nodes ↔ WebGPUNodes
getter/setter pair
objectCache ↔ WeakMap
getter/setter pair
pipelines ↔ List
getter/setter pair
renderer ↔ WebGPURenderer
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sampleCount ↔ int
getter/setter pair
stages ↔ _Stages
getter/setter pair

Methods

dispose() → dynamic
get(dynamic object) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited