WebGPUStorageBuffer class

Inheritance

Constructors

WebGPUStorageBuffer(dynamic name, dynamic attribute)

Properties

attribute ↔ dynamic
getter/setter pair
bufferGPU ↔ dynamic
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isShared ↔ bool
getter/setter pairinherited
name ↔ String
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ dynamic
getter/setter pairinherited
usage ↔ int
getter/setter pair
visibility ↔ dynamic
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setVisibility(dynamic visibility) → dynamic
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited