WebGPUUniform class

Implementers

Constructors

WebGPUUniform(dynamic name, [dynamic value = null])

Properties

boundary ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
itemSize ↔ int
getter/setter pair
name ↔ String
getter/setter pair
offset ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ dynamic
getter/setter pair

Methods

getValue() → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setValue(dynamic value) → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited